==> cms-db_v0.7.5.tar.gz: admin/url.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('root');
include('locale.inc.php');
$locale = new LocalizingClass('url');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('title') ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="style.css">
		<link rel="stylesheet" type="text/css" href="<?php include('mobile.inc.php'); echo mobile() ? 'anchormenu-mobile.css' : 'anchormenu.css'; ?>" />
	</head>
	<body>

		<h1><?php locale('desc_settings') ?></h1>

		<div class="anchormenu"><span class="leftcorner">&nbsp;</span><ul><li><a href="users.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_usersettings') ?></a></li><li><a href="commonsettings.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_commonsettings') ?></a></li><li><a href="url.php?<?php echo SID ?>" class="nonewtab active"><?php locale('link_urlsettings') ?></a></li><li><a href="adminsettings.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_adminsettings') ?></a></li><li><a href="locale.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_localesettings') ?></a></li></ul><span class="rightcorner">&nbsp;</span></div>

		<?php
		if (isset($_POST['button'])) {
		if ($_POST['generate_urlabs'] == 'on') {
			$urlabsolute = ereg_replace("/admin/url.php?(.*)",'', $_SERVER["REQUEST_URI"]);
		} else {
			$urlabsolute = $_POST['urlabsolute'];
		}
			$writethis = '<?php
			$urlbefore = "'.$_POST["urlbefore"].'";
			$urlafter = "'.$_POST["urlafter"].'";
			$urlabsolute = "'.$urlabsolute.'";
			?>';
			$datei = fopen('../data/settings/url.inc.php','w+');
			fwrite($datei,$writethis);
			fclose($datei);
			include('cache.inc.php');
			clear_cache_complete();
			echo '<p class="hint">'.locale('desc_settings-saved',true).'</p>';
		}
		include("../data/settings/url.inc.php");
		?>

		<h2><?php locale('title') ?></h2>
		<p>
			<form action="url.php?<?php echo SID ?>" method="post">
						<?php locale('label_urlbefore') ?> <input type="text" name="urlbefore" value="<?php echo $urlbefore ?>" /><br />
						<?php locale('label_urlafter') ?> <input type="text" name="urlafter" value="<?php echo $urlafter ?>" /><br />
						<?php locale('label_urlabsolute') ?> <input type="text" name="urlabsolute" value="<?php echo $urlabsolute ?>" />
						<input type="checkbox" name="generate_urlabs" id="generate_urlabs">
						<label for="generate_urlabs"><?php locale('label_generate') ?></label>
						<br />
						<input type="submit" name="button" value="<?php locale('button_save') ?>">
				 </form>
		</p>
		<h3><?php locale('title_note') ?></h3>
		<p>
			<?php locale('desc_no-rewriting') ?>
			<ul>
				<li><b><?php locale('label_urlbefore') ?></b> <i>index.php?</i></li>
				<li><b><?php locale('label_urlafter') ?></b> (<?php locale('desc_nothing') ?>)</li>
				<li><b><?php locale('label_urlabsolute') ?></b> <?php printf(locale('desc_activate-automatic',true),locale('label_generate',true)) ?></li>
			</ul>
		</p>
		<h3><?php locale('title_example') ?></h3>
		<p>
			<?php locale('desc_example') ?>
			<ul>
				<li><b><?php locale('label_urlbefore') ?></b> <i>/site/</i></li>
				<li><b><?php locale('label_urlafter') ?></b> <i>.html</i> (<?php locale('desc_with-dot') ?>)</li>
				<li><b><?php locale('label_urlabsolute') ?></b> <i>/cms</i> (<?php locale('desc_alternative') ?> <?php printf(locale('desc_activate-automatic',true),locale('label_generate',true)) ?>)</li>
			</ul>
		</p>
		<p>
			<?php locale('desc_htaccess') ?>
		</p>
		<pre>RewriteEngine on 
RewriteRule ^site/(.*).html$ /cms/index.php?$1</pre>

	</body>
</html>

==> cms-db_v0.7.9.tar.gz: admin/url.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('root');
include('locale.inc.php');
$locale = new LocalizingClass('url');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('title') ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="style.css">
		<link rel="stylesheet" type="text/css" href="<?php include('mobile.inc.php'); echo mobile() ? 'style-extra-mobile.css' : 'style-extra.css'; ?>" />
	</head>
	<body>

		<h1><?php locale('desc_settings') ?></h1>

		<div class="anchormenu"><span class="leftcorner">&nbsp;</span><ul><li><a href="users.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_usersettings') ?></a></li><li><a href="commonsettings.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_commonsettings') ?></a></li><li><a href="url.php?<?php echo SID ?>" class="nonewtab active"><?php locale('link_urlsettings') ?></a></li><li><a href="adminsettings.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_adminsettings') ?></a></li><li><a href="locale.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_localesettings') ?></a></li></ul><span class="rightcorner">&nbsp;</span></div>

		<?php
		if (isset($_POST['button'])) {
		if ($_POST['generate_urlabs'] == 'on') {
			$urlabsolute = ereg_replace("/admin/url.php?(.*)",'', $_SERVER["REQUEST_URI"]);
		} else {
			$urlabsolute = $_POST['urlabsolute'];
		}
			$writethis = '<?php
			$urlbefore = "'.$_POST["urlbefore"].'";
			$urlafter = "'.$_POST["urlafter"].'";
			$urlabsolute = "'.$urlabsolute.'";
			?>';
			$datei = fopen('../data/settings/url.inc.php','w+');
			fwrite($datei,$writethis);
			fclose($datei);
			include('cache.inc.php');
			clear_cache_complete();
			echo '<p class="hint">'.locale('desc_settings-saved',true).'</p>';
		}
		include("../data/settings/url.inc.php");
		?>

		<h2><?php locale('title') ?></h2>
		<p>
			<form action="url.php?<?php echo SID ?>" method="post">
						<?php locale('label_urlbefore') ?> <input type="text" name="urlbefore" value="<?php echo $urlbefore ?>" /><br />
						<?php locale('label_urlafter') ?> <input type="text" name="urlafter" value="<?php echo $urlafter ?>" /><br />
						<?php locale('label_urlabsolute') ?> <input type="text" name="urlabsolute" value="<?php echo $urlabsolute ?>" />
						<input type="checkbox" name="generate_urlabs" id="generate_urlabs">
						<label for="generate_urlabs"><?php locale('label_generate') ?></label>
						<br />
						<input type="submit" name="button" value="<?php locale('button_save') ?>">
				 </form>
		</p>
		<h3><?php locale('title_note') ?></h3>
		<p>
			<?php locale('desc_no-rewriting') ?>
			<ul>
				<li><b><?php locale('label_urlbefore') ?></b> <i>index.php?</i></li>
				<li><b><?php locale('label_urlafter') ?></b> (<?php locale('desc_nothing') ?>)</li>
				<li><b><?php locale('label_urlabsolute') ?></b> <?php printf(locale('desc_activate-automatic',true),locale('label_generate',true)) ?></li>
			</ul>
		</p>
		<h3><?php locale('title_example') ?></h3>
		<p>
			<?php locale('desc_example') ?>
			<ul>
				<li><b><?php locale('label_urlbefore') ?></b> <i>/site/</i></li>
				<li><b><?php locale('label_urlafter') ?></b> <i>.html</i> (<?php locale('desc_with-dot') ?>)</li>
				<li><b><?php locale('label_urlabsolute') ?></b> <i>/cms</i> (<?php locale('desc_alternative') ?> <?php printf(locale('desc_activate-automatic',true),locale('label_generate',true)) ?>)</li>
			</ul>
		</p>
		<p>
			<?php locale('desc_htaccess') ?>
		</p>
		<pre>RewriteEngine on 
RewriteRule ^site/(.*).html$ /cms/index.php?$1</pre>

	</body>
</html>
